#
# spec file for package amsynth
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           amsynth
Version:        1.13.2
Release:        1.4
Summary:        Analog modelling (a.k.a virtual analog) software synthesizer
License:        GPL-2.0-or-later
URL:            https://amsynth.github.io/
Source:         https://github.com/amsynth/amsynth/archive/refs/tags/release-%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  autoconf-archive
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  libtool
%ifnarch %ix86 %arm
BuildRequires:  pandoc
%endif
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(dssi)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(liblo)
BuildRequires:  pkgconfig(lv2)
BuildRequires:  pkgconfig(sndfile)

%description
Amsynth is an analog modelling (a.k.a virtual analog) software synthesizer.
It mimics the operation of early analog subtractive synthesizers with
classic oscillator waveforms, envelopes, filter, modulation and effects.
The aim is to make it easy to create and modify sounds.

Features:
 * Dual oscillators (sine / saw / square / noise) with hard sync
 * 12/24 dB/oct resonant filter (low-pass / high-pass / band-pass / notch)
 * Mono / poly / legato keyboard modes
 * Dual ADSR envelope generators (filter & amplitude)
 * LFO which can modulate the oscillators, filter, and amplitude
 * Distortion and reverb
 * Hundreds of presets

There are currently several different ways to run amsynth:
 * Stand-alone application using JACK, ALSA or OSS
 * DSSI plug-in
 * LV2 plug-in
 * VST plug-in

%package plugin-dssi
Summary:        Analog modelling (a.k.a virtual analog) software synthesizer
Requires:       %{name} = %{version}
Requires:       dssi

%description plugin-dssi
Amsynth is an analog modelling (a.k.a virtual analog) software synthesizer.
It mimics the operation of early analog subtractive synthesizers with
classic oscillator waveforms, envelopes, filter, modulation and effects.
The aim is to make it easy to create and modify sounds.

Features:
 * Dual oscillators (sine / saw / square / noise) with hard sync
 * 12/24 dB/oct resonant filter (low-pass / high-pass / band-pass / notch)
 * Mono / poly / legato keyboard modes
 * Dual ADSR envelope generators (filter & amplitude)
 * LFO which can modulate the oscillators, filter, and amplitude
 * Distortion and reverb
 * Hundreds of presets

There are currently several different ways to run amsynth:
 * Stand-alone application using JACK, ALSA or OSS
 * DSSI plug-in
 * LV2 plug-in
 * VST plug-in

This package includes the DSSI implementation of the synthesizer.

%package plugin-lv2
Summary:        Analog modelling (a.k.a virtual analog) software synthesizer
Requires:       %{name} = %{version}

%description plugin-lv2
Amsynth is an analog modelling (a.k.a virtual analog) software synthesizer.
It mimics the operation of early analog subtractive synthesizers with
classic oscillator waveforms, envelopes, filter, modulation and effects.
The aim is to make it easy to create and modify sounds.

Features:
 * Dual oscillators (sine / saw / square / noise) with hard sync
 * 12/24 dB/oct resonant filter (low-pass / high-pass / band-pass / notch)
 * Mono / poly / legato keyboard modes
 * Dual ADSR envelope generators (filter & amplitude)
 * LFO which can modulate the oscillators, filter, and amplitude
 * Distortion and reverb
 * Hundreds of presets

There are currently several different ways to run amsynth:
 * Stand-alone application using JACK, ALSA or OSS
 * DSSI plug-in
 * LV2 plug-in
 * VST plug-in

This package includes the LV2 implementation of the synthesizer.

%package plugin-vst
Summary:        Analog modelling (a.k.a virtual analog) software synthesizer
Requires:       %{name} = %{version}

%description plugin-vst
Amsynth is an analog modelling (a.k.a virtual analog) software synthesizer.
It mimics the operation of early analog subtractive synthesizers with
classic oscillator waveforms, envelopes, filter, modulation and effects.
The aim is to make it easy to create and modify sounds.

Features:
 * Dual oscillators (sine / saw / square / noise) with hard sync
 * 12/24 dB/oct resonant filter (low-pass / high-pass / band-pass / notch)
 * Mono / poly / legato keyboard modes
 * Dual ADSR envelope generators (filter & amplitude)
 * LFO which can modulate the oscillators, filter, and amplitude
 * Distortion and reverb
 * Hundreds of presets

There are currently several different ways to run amsynth:
 * Stand-alone application using JACK, ALSA or OSS
 * DSSI plug-in
 * LV2 plug-in
 * VST plug-in

This package includes the VST implementation of the synthesizer.

%lang_package

%prep
%autosetup -n %{name}-release-%{version} -p1

%build
mkdir -p m4
autoreconf -fiv
intltoolize -f
%configure
make %{?_smp_mflags}

%install
%make_install
%suse_update_desktop_file %{name} Audio Midi
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_datadir}/%{name}/skins/

%if 0%{?suse_version} < 1550
%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%endif

%files
%license COPYING
%doc AUTHORS README NEWS
%{_bindir}/amsynth
%{_datadir}/amsynth
%{_datadir}/applications/amsynth.desktop
%{_datadir}/icons/hicolor/*/apps/amsynth.*
%dir %{_datadir}/appdata
%{_datadir}/appdata/amsynth.appdata.xml
%ifnarch %ix86 %arm
%{_mandir}/man1/amsynth.1%{?ext_man}
%endif

%files plugin-dssi
%{_libdir}/dssi/
%dir %{_datadir}/appdata
%{_datadir}/appdata/dssi-amsynth-plugin.metainfo.xml

%files plugin-lv2
%{_libdir}/lv2/
%dir %{_datadir}/appdata
%{_datadir}/appdata/lv2-amsynth-plugin.metainfo.xml

%files plugin-vst
%{_libdir}/vst/
%dir %{_datadir}/appdata
%{_datadir}/appdata/vst-amsynth-plugin.metainfo.xml

%files lang -f %{name}.lang
%ifnarch %ix86 %arm
%{_mandir}/de/man1/amsynth.1%{?ext_man}
%{_mandir}/fr/man1/amsynth.1%{?ext_man}
%endif

%changelog
* Tue Feb 14 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.13.2:
  * Fixed a packaging error that caused preset banks to be omitted.
* Fri Jan 27 2023 munix9@googlemail.com
- Switch to the full source code archive to get the missing
  data files for amsynth.lv2
* Sat Jan 21 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.13.1:
  * Fixed a crash when parsing XSettings on some systems
    (gh#amsynth/amsynth#221).
* Sun Jul 17 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- Update to version 1.13.0
  * Fixed intermittent unexpected MIDI output in response to MIDI CC input.
  * Fixed VST plugin UI updates in response to host parameter changes.
  * Added HiDPI scaling support to VST plugin UI.
  * Added version info to plugin pop-up menu.
* Fri Mar 25 2022 Dirk Müller <dmueller@suse.com>
- skip pandoc for arm 32bit platforms as well
* Sat Jan  8 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.12.4:
  * Fixed lv2 .ttl syntax error - gh#amsynth/amsynth#199
- Changes from version 1.12.3:
  * Added PatriksBank04 and PatriksBank05 - gh#amsynth/amsynth#197
  * Fixed click when playing a note for the first time -
    gh#amsynth/amsynth#196
  * Stopped vendoring lv2 headers; install lv2-dev (or similar)
    via your package manager.
- New BuildRequries: pkgconfig(lv2) required to build lv2 plugin.
* Fri Sep 10 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Do not build man pages on %%ix86: pandoc does not exist on
  intel/i586.
- Do not recommend the -lang package: the autogenerated -lang
  package already has appropriate supplements.
* Sun Nov 29 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.12.2:
  * Fixed a regression in 1.12.0 that broke ALSA MIDI
    [gh#amsynth/amsynth#181].
* Sun Nov 15 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.12.1:
  * Fixed LV2 manifest format error [gh#amsynth/amsynth#178].
* Mon Nov  9 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.12.0:
  + Improved HiDPI autodetection and added
  - -force-device-scale-factor command line option
    (gh#amsynth/amsynth#174).
  + Presets are now available to be loaded in VST hosts using the
    generic GUI (e.g. REAPER).
  + Fixed a bug that caused MIDI channel and polyphony settings
    from the command line or configuration file to be ignored
    (gh#amsynth/amsynth#170).
  + Fixed a bug that caused MIDI channel setting to be ignored
    when sending MIDI over JACK (gh#amsynth/amsynth#170).
  + Fixed a MIDI parsing bug in the VST plugin that caused stuck
    notes in REAPER.
  + Fixed a crash when compiled with LASH support but without a
    LASH server running.
* Mon Sep 21 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.11.0:
  + Added mouse wheel support for controls.
  + Implemented UI upscaling for background and controls on HiDPI
    displays.
  + Fixed a regression in 1.10.0 that changed the sound of patches
    using ring modulation.
  + Fixed LV2 lint error caused by missing minorVersion and
    microVersion.
  + Removed dependency on oscpack for Non Session Manager support.
* Tue Jun  9 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.10.0:
  + Implemented smoothing / de-zippering to improve sound quality
    while adjusting parameters.
  + amsynth user files (config, banks, etc.) now live in
    XDG-compliant directories.
  + Added jack_autoconnect configuration option.
  + Disabled VST GUI in REAPER.
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Tue Apr 23 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.9.0:
  + Added support for NSM (Non Session Manager)
  + Improved FreeBSD OSS audio support
  + Sustain pedal can now be used in Mono and Legato modes
  + JACK MIDI inputs are now automatically connected
  + Fixed a crash in MIDI learn dialog when receiving CC messages
  + Other minor bug fixes
- Drop amsynth-install-translated-appdata.patch: incorporated
  upstream; drop associated BuildRequries: libtool, autoconf,
  and automake, and do not run autoreconf any more.
- Conditionalise post(un) scriptlets to run only for openSUSE 15.1
  and earlier; for tumbleweed, they are taken care of by rpm file
  triggers.
* Tue Apr  3 2018 tchvatal@suse.com
- Use %%license macro
- Drop lash-1.0 dependency as we try to reduce it (remove from TW)
* Mon Jun 26 2017 badshah400@gmail.com
- Update to version 1.8.0:
  + Controls can now be reset to their default value via a
    double-click.
  + Alternate tuning scales & keyboard maps can now be loaded in
    plug-ins.
  + Fixed an issue where bank switching via MIDI caused jack
    zombification.
  + Removed dependency on gtkmm (gtk is still required for the
    UI).
- Add amsynth-install-translated-appdata.patch to fix installation
  of translated metainfo files; introduces BuildRequries on
  automake, autconf and libtool. Patch sent upstream.
- Package metainfo files for plugins.
- Drop BuildRequries on gtkmm.
* Wed Mar 29 2017 badshah400@gmail.com
- Update to version 1.7.1:
  + Fixed MIDI channel filtering.
  + Fixed corrupt preset names in dssi plugin.
  + General UI and menu item improvements.
  + Improvements to translations.
  + Added a man page.
- Drop amsynth-install-appdata.patch (and associated buildrequires
  on libtool): incorporated upstream.
- Generate (add BuildRequires: pandoc) and install new man files
  (new in version 1.7.1).
* Tue Nov 15 2016 badshah400@gmail.com
- Initial package.
- Add amsynth-install-appdata.patch: Add a translatable appdata
  file and install it using autotool; patch-feature-opensuse for
  now but sent upstream.
